<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de" sourcelanguage="en_US">
<context>
    <name>Application</name>
    <message>
        <location filename="../src/application.cpp" line="427"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="104"/>
        <location filename="../src/application.cpp" line="150"/>
        <source>Draw</source>
        <translation>Zeichnen</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="426"/>
        <source>You can import up to 30 pictures, please try again!</source>
        <translation>Sie können bis zu 30 Bilder importieren, bitte versuchen Sie es erneut!</translation>
    </message>
</context>
<context>
    <name>BlurWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="100"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="110"/>
        <source>Blur</source>
        <translation>Weichzeichnen</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="123"/>
        <source>Mosaic</source>
        <translation>Mosaik</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/blurwidget.cpp" line="146"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
</context>
<context>
    <name>CAbstractProcessDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cprogressdialog.cpp" line="105"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
</context>
<context>
    <name>CAlphaControlWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/calphacontrolwidget.cpp" line="65"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
</context>
<context>
    <name>CCutDialog</name>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="41"/>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="42"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/ccutdialog.cpp" line="47"/>
        <source>Do you want to save the cropped image?</source>
        <translation>Möchten Sie das zugeschnittene Bild speichern?</translation>
    </message>
</context>
<context>
    <name>CCutTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ccuttool.cpp" line="90"/>
        <source>Crop (C)</source>
        <translation>Zuschneiden (C)</translation>
    </message>
</context>
<context>
    <name>CCutWidget</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="230"/>
        <source>Dimensions</source>
        <translation>Abmessungen</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="245"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="295"/>
        <source>Aspect ratio</source>
        <translation>Seitenverhältnis</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="336"/>
        <source>Free</source>
        <translation>Frei</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="343"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
</context>
<context>
    <name>CEllipseTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cellipsetool.cpp" line="57"/>
        <source>Ellipse (O)</source>
        <translation>Ellipse (O)</translation>
    </message>
</context>
<context>
    <name>CEraserTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="98"/>
        <source>Eraser (E)</source>
        <translation>Radierer (E)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cerasertool.cpp" line="113"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
</context>
<context>
    <name>CExportImageDialog</name>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="548"/>
        <source>Percentage</source>
        <translation>Prozent</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="562"/>
        <source>Pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="564"/>
        <source>Dimensions:</source>
        <translation>Abmessungen:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="586"/>
        <source>Lock aspect ratio</source>
        <translation>Seitenverhältnis sperren</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="595"/>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="600"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="611"/>
        <source>pixels</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="605"/>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="868"/>
        <source>It supports up to 10,000 pixels</source>
        <translation>Er unterstützt bis zu 10.000 Pixel</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="98"/>
        <source>Unnamed</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="173"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="186"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="188"/>
        <source>Documents</source>
        <translation>Dokumente</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="189"/>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="190"/>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="191"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="192"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="193"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="207"/>
        <source>Select other directories</source>
        <translation>Andere Verzeichnisse auswählen</translation>
    </message>
    <message>
        <source>jpg</source>
        <translation type="vanished">jpg</translation>
    </message>
    <message>
        <source>png</source>
        <translation type="vanished">png</translation>
    </message>
    <message>
        <source>bmp</source>
        <translation type="vanished">bmp</translation>
    </message>
    <message>
        <source>tif</source>
        <translation type="vanished">tif</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">pdf</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="265"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="266"/>
        <source>Save to:</source>
        <translation>Speichern als:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="268"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="269"/>
        <source>Quality:</source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="275"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="281"/>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="276"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="282"/>
        <source>Replace</source>
        <translation>Überschreiben</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="406"/>
        <source>This file will be hidden if the file name starts with a dot (.). Do you want to hide it?</source>
        <translation>Diese Datei wird versteckt, wenn der Dateiname mit einem Punkt (.) beginnt. Möchten Sie sie verstecken?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="407"/>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="421"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="423"/>
        <source>The file name is too long</source>
        <translation>Der Dateiname ist zu lang</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="506"/>
        <source>%1 
 already exists, do you want to replace it?</source>
        <translation>%1 
existiert bereits. Wollen Sie es überschreiben?</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/cexportimagedialog.cpp" line="866"/>
        <source>At least one pixel please</source>
        <translation>Bitte mindestens ein Pixel</translation>
    </message>
</context>
<context>
    <name>CLineTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/clinetool.cpp" line="58"/>
        <source>Line (L)</source>
        <translation>Strich (L)</translation>
    </message>
</context>
<context>
    <name>CPenTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="79"/>
        <source>Pencil (P)</source>
        <translation>Stift (P)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="96"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="124"/>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="167"/>
        <source>Watercolor</source>
        <translation>Wasserfarbe</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="168"/>
        <source>Calligraphy pen</source>
        <translation>Kalligrafie-Stift</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="169"/>
        <source>Crayon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpentool.cpp" line="514"/>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
</context>
<context>
    <name>CPictureTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="87"/>
        <source>Import (I)</source>
        <translation>Importieren (I)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="114"/>
        <source>Rotate 90° CCW</source>
        <translation>Um 90° gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="132"/>
        <source>Rotate 90° CW</source>
        <translation>Um 90° im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="149"/>
        <source>Flip horizontally</source>
        <translation>Horizontal spiegeln</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="169"/>
        <source>Flip vertically</source>
        <translation>Vertikal spiegeln</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="188"/>
        <source>Auto fit</source>
        <translation>Automatisch anpassen</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpicturetool.cpp" line="232"/>
        <source>Import Picture</source>
        <translation>Bild importieren</translation>
    </message>
</context>
<context>
    <name>CPolygonTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="69"/>
        <source>Polygon (H)</source>
        <translation>Polygon (H)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygontool.cpp" line="86"/>
        <source>Sides</source>
        <translation>Seiten</translation>
    </message>
</context>
<context>
    <name>CPolygonalStarTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="49"/>
        <source>Star (F)</source>
        <translation>Stern (F)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="90"/>
        <source>Points</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cpolygonalstartool.cpp" line="97"/>
        <source>Radius</source>
        <translation>Radius</translation>
    </message>
</context>
<context>
    <name>CRectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="68"/>
        <source>Rectangle (R)</source>
        <translation>Rechteck (R)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="136"/>
        <source>Fill</source>
        <translation>Füllen</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="142"/>
        <source>Corner Radius</source>
        <translation>Eckenradius</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="273"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
</context>
<context>
    <name>CSelectTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="90"/>
        <source>Select (V)</source>
        <translation>Auswahl (V)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/cselecttool.cpp" line="124"/>
        <source>Unnamed</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>CTextTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="68"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="99"/>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="229"/>
        <source>Input text here</source>
        <translation>Text hier eingeben</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="328"/>
        <source>Weight</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="344"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="469"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
</context>
<context>
    <name>CTriangleTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/ctriangletool.cpp" line="62"/>
        <source>Triangle (S)</source>
        <translation>Dreieck (S)</translation>
    </message>
</context>
<context>
    <name>ColorPanel</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/colorpanel.cpp" line="175"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
</context>
<context>
    <name>DrawAttribution::CGroupButtonWgt</name>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="487"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="499"/>
        <source>Group</source>
        <translation>Gruppieren</translation>
    </message>
    <message>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="490"/>
        <location filename="../src/frame/AttributesWidgets/private/cattributeitemwidget.cpp" line="507"/>
        <source>Ungroup</source>
        <translation>Gruppierung aufheben</translation>
    </message>
</context>
<context>
    <name>DrawDialog</name>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="43"/>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="44"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/drawdialog.cpp" line="47"/>
        <source>Save the current contents?</source>
        <translation>Die aktuellen Inhalte speichern?</translation>
    </message>
</context>
<context>
    <name>FileHander</name>
    <message>
        <location filename="../src/service/filehander.cpp" line="596"/>
        <source>Opening...</source>
        <translation>Wird geöffnet ...</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="623"/>
        <source>Saving...</source>
        <translation>Wird gespeichert ...</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="650"/>
        <source>Damaged file, unable to open it</source>
        <translation>Beschädigte Datei, kann nicht geöffnet werden</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="705"/>
        <location filename="../src/service/filehander.cpp" line="828"/>
        <source>The file does not exist</source>
        <translation>Die Datei existiert nicht</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="724"/>
        <source>Unable to open &quot;%1&quot;, unsupported file format</source>
        <translation>„%1“ kann nicht geöffnet werden, nicht unterstütztes Dateiformat</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="749"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>Der Dateiname darf \/:*?&quot;&lt;&gt;| nicht enthalten</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="839"/>
        <source>Unable to open the write-only file &quot;%1&quot;</source>
        <translation>Sie haben nicht die Berechtigung, die Datei &quot;%1&quot; zu öffnen</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="852"/>
        <source>This file is read-only, please save with another name</source>
        <translation>Diese Datei ist schreibgeschützt, bitte speichern Sie unter einem anderen Namen.</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="860"/>
        <source>You do not have permission to save files here, please change and retry</source>
        <translation>Sie dürfen hier keine Dateien speichern. Bitte wählen Sie einen anderen Ort und versuchen Sie es erneut.</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="881"/>
        <source>The file is incompatible with the old app, please install the latest version</source>
        <translation>Die Datei ist mit dieser Version der App inkompatibel. Bitte installieren Sie die neueste Version.</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="899"/>
        <source>Unable to open the broken file &quot;%1&quot;</source>
        <translation>Beschädigte Datei „%1“ kann nicht geöffnet werden</translation>
    </message>
</context>
<context>
    <name>FileSelectDialog</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="202"/>
        <source>The file name must not contain \/:*?&quot;&lt;&gt;|</source>
        <translation>Der Dateiname darf \/:*?&quot;&lt;&gt;| nicht enthalten</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="204"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="231"/>
        <source>Cannot save it as %1, since the file in that name is open now.
Please save it in another name or close that file and try again.</source>
        <translation>Es kann nicht mit dem Namen %1 gespeichert werden, da die Datei mit diesem Namen bereits geöffnet ist. 
Bitte wählen Sie einen anderen Namen oder schließen Sie die Datei und versuchen Sie es erneut.</translation>
    </message>
</context>
<context>
    <name>IBlurTool</name>
    <message>
        <location filename="../src/drawshape/drawTools/cmasicotool.cpp" line="148"/>
        <source>Blur (B)</source>
        <translation>Weichzeichnen (B)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="105"/>
        <source>Draw</source>
        <translation>Zeichnen</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export successful</source>
        <translation>Exportieren erfolgreich</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="200"/>
        <source>Export failed</source>
        <translation>Exportieren fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="228"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
</context>
<context>
    <name>PageContext</name>
    <message>
        <location filename="../src/drawshape/cdrawparamsigleton.cpp" line="66"/>
        <source>Unnamed</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>PageView</name>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="322"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="666"/>
        <source>Layer</source>
        <translation>Ebene</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="324"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="683"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="329"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="684"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="334"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="685"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="341"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="686"/>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="348"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="692"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="354"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="687"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="363"/>
        <location filename="../src/frame/cgraphicsview.cpp" line="688"/>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="372"/>
        <source>Raise Layer</source>
        <translation>Ebene nach oben</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="377"/>
        <source>Lower Layer</source>
        <translation>Ebene nach unten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="382"/>
        <source>Layer to Top</source>
        <translation>Ebene ganz nach oben</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="387"/>
        <source>Layer to Bottom</source>
        <translation>Ebene ganz nach unten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="416"/>
        <source>Group</source>
        <translation>Gruppieren</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="421"/>
        <source>Ungroup</source>
        <translation>Gruppierung aufheben</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="427"/>
        <source>Align</source>
        <translation>Ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="430"/>
        <source>Align left</source>
        <translation>Linksbündig ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="435"/>
        <source>Horizontal centers</source>
        <translation>Horizontal mittig</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="440"/>
        <source>Align right</source>
        <translation>Rechtsbündig ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="445"/>
        <source>Align top</source>
        <translation>Oben ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="450"/>
        <source>Vertical centers</source>
        <translation>Vertikal mittig</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="455"/>
        <source>Align bottom</source>
        <translation>Unten ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="460"/>
        <source>Distribute horizontal space</source>
        <translation>Horizontalen Platz verteilen</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="462"/>
        <source>Distribute vertical space</source>
        <translation>Vertikalen Platz verteilen</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="689"/>
        <source>Text Align Left</source>
        <translation>Text linksbündig ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="690"/>
        <source>Text Align Right</source>
        <translation>Text rechtsbündig ausrichten</translation>
    </message>
    <message>
        <location filename="../src/frame/cgraphicsview.cpp" line="691"/>
        <source>Text Align Center</source>
        <translation>Text zentriert ausrichten</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/frame/mainwindow.cpp" line="75"/>
        <location filename="../src/frame/cviewmanagement.cpp" line="202"/>
        <source>File not saved</source>
        <translation>Datei nicht gespeichert</translation>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/ctexttool.cpp" line="355"/>
        <source>Source Han Sans CN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/drawshape/drawTools/crecttool.cpp" line="84"/>
        <source>Stroke</source>
        <translation>Strich</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="103"/>
        <source>The blur effect will be lost as the file is in old version. Proceed to open it?</source>
        <translation>Der Weichzeichnungseffekt wird verloren gehen, da die Datei in einer alten Version vorliegt. Möchten Sie sie wirklich öffnen?</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="104"/>
        <location filename="../src/service/filehander.cpp" line="129"/>
        <location filename="../src/service/filehander.cpp" line="203"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="757"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="385"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="128"/>
        <location filename="../src/service/filehander.cpp" line="202"/>
        <source>The file is in an older version, and the properties of elements will be changed. Proceed to open it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/service/filehander.cpp" line="462"/>
        <source>Unable to save. There is not enough disk space.</source>
        <translation>Speichern nicht möglich. Es ist nicht genug Speicherplatz vorhanden.</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="287"/>
        <source>Unnamed</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="300"/>
        <source>The dimensions of %1 exceed the canvas. How to display it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Keep original size</source>
        <translation>Originalgröße beibehalten</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="301"/>
        <source>Auto fit</source>
        <translation>Automatisch anpassen</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="296"/>
        <source>Apply to all</source>
        <translation>Auf alle anwenden</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="755"/>
        <source>%1 has been modified in other programs. Do you want to reload it?</source>
        <translation>%1 wurde in anderen Programmen geändert. Möchten Sie sie neu laden?</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="756"/>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
    <message>
        <location filename="../src/frame/ccentralwidget.cpp" line="1289"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1691"/>
        <source>Import failed: no more than 10,000 pixels please</source>
        <translation>Importieren fehlgeschlagen: bitte nicht mehr als 10.000 Pixel</translation>
    </message>
    <message>
        <location filename="../src/widgets/dialog/dialog.h" line="45"/>
        <location filename="../src/frame/AttributesWidgets/private/ccutwidget.cpp" line="374"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="37"/>
        <location filename="../src/frame/ccentralwidget.cpp" line="1224"/>
        <source>Opening...</source>
        <translation>Wird geöffnet ...</translation>
    </message>
    <message>
        <location filename="../src/widgets/progresslayout.cpp" line="158"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="vanished">Alles auswählen</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="vanished">Ausschneiden</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="vanished">Rückgängig</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="vanished">Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="vanished">Einfügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Löschen</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="vanished">Gruppieren</translation>
    </message>
    <message>
        <source>Ungroup</source>
        <translation type="vanished">Gruppierung aufheben</translation>
    </message>
    <message>
        <source>pdf</source>
        <translation type="vanished">pdf</translation>
    </message>
    <message>
        <location filename="../src/application.cpp" line="72"/>
        <location filename="../src/application.cpp" line="80"/>
        <source>DDF Drawings</source>
        <translation>DDF-Zeichnungen</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="34"/>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="35"/>
        <source>Drawing</source>
        <translation>Zeichnung</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="36"/>
        <source>Shapes/Images</source>
        <translation>Formen/Bilder</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="37"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="38"/>
        <source>Align</source>
        <translation>Ausrichten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="42"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="43"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="44"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="45"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="46"/>
        <source>Save as</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="47"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="50"/>
        <source>Select</source>
        <translation>Auswahl</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="51"/>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="52"/>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="53"/>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="54"/>
        <source>Triangle</source>
        <translation>Dreieck</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="55"/>
        <source>Star</source>
        <translation>Stern</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="56"/>
        <source>Polygon</source>
        <translation>Polygon</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="57"/>
        <source>Line</source>
        <translation>Strich</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="59"/>
        <source>Pencil</source>
        <translation>Stift</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="58"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="60"/>
        <source>Eraser</source>
        <translation>Radierer</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="61"/>
        <source>Blur</source>
        <translation>Weichzeichnen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="62"/>
        <source>Crop</source>
        <translation>Zuschneiden</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="63"/>
        <source>Expand canvas</source>
        <translation>Leinwand vergrößern</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="64"/>
        <source>Shrink canvas</source>
        <translation>Leinwand verkleinern</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="69"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="70"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="71"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="72"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="73"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="74"/>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="75"/>
        <source>Group</source>
        <translation>Gruppieren</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="76"/>
        <source>Ungroup</source>
        <translation>Gruppierung aufheben</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="77"/>
        <source>Raise Layer</source>
        <translation>Ebene nach oben</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="78"/>
        <source>Lower Layer</source>
        <translation>Ebene nach unten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="79"/>
        <source>Layer to Top</source>
        <translation>Ebene ganz nach oben</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="80"/>
        <source>Layer to Bottom</source>
        <translation>Ebene ganz nach unten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>Verknüpfungen anzeigen</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="87"/>
        <source>Align left</source>
        <translation>Linksbündig ausrichten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="88"/>
        <source>Align right</source>
        <translation>Rechtsbündig ausrichten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="89"/>
        <source>Horizontal centers</source>
        <translation>Horizontal mittig</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="90"/>
        <source>Align top</source>
        <translation>Oben ausrichten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="91"/>
        <source>Align bottom</source>
        <translation>Unten ausrichten</translation>
    </message>
    <message>
        <location filename="../src/utils/shortcut.cpp" line="92"/>
        <source>Vertical centers</source>
        <translation>Vertikal mittig</translation>
    </message>
</context>
<context>
    <name>TabBarWgt</name>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="120"/>
        <source>Close tab</source>
        <translation>Tab schließen</translation>
    </message>
    <message>
        <location filename="../src/frame/cmultiptabbarwidget.cpp" line="125"/>
        <source>Close other tabs</source>
        <translation>Andere Tabs schließen</translation>
    </message>
</context>
<context>
    <name>TopTilte</name>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="173"/>
        <source>New</source>
        <translation>Neu</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="178"/>
        <source>Open</source>
        <translation>Öffnen</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="199"/>
        <location filename="../src/frame/toptoolbar.cpp" line="225"/>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="189"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="194"/>
        <source>Save as</source>
        <translation>Speichern als</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="209"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="242"/>
        <source>Draw</source>
        <translation>Zeichnen</translation>
    </message>
    <message>
        <location filename="../src/frame/toptoolbar.cpp" line="245"/>
        <source>Draw is a lightweight drawing tool for users to freely draw and simply edit images. </source>
        <translation>Draw ist ein einfaches Zeichenwerkzeug, mit dem Benutzer Bilder frei zeichnen und einfach bearbeiten können.</translation>
    </message>
</context>
</TS>